@@ -79,15 +79,12 @@ def ipn(request, get=False):
 			except Exception, e:
 				raise NotificationFailedValidation(e)
 		else:
-			# If the form invalidates due to duplicate receipt, we go ahead and return 200 anyway.
-			if 'receipt' in form.errors:
-				if form.errors['receipt'][0] == u'Notification with this Receipt already exists.':
+			if '__all__' in form.errors:
+				if form.errors['__all__'][0] == u'Notification with this Receipt and Transaction type already exists.':
 					notification = Notification.objects.get(receipt=form.data['receipt'])
 					logger.info('Notification recognized as duplicate. Returning OK.')
-					if settings.CLICKBANK_DEBUG:
-						logger.debug('Resending Signals')
-						notification.send_signals()
 					return HttpResponse(notification.id)
+
 			raise NotificationFailedValidation('{0}\n{1}\n{2}'.format(form.errors, mapped_data, data))
 
 		notification.initialize(request)
